@@ -502,3 +502,94 @@ def test_ldap__password_change_no_grace_logins_left(
 
     rc, _, _, _ = client.auth.parametrize(method).password_with_output("user1", "Secret123")
     assert rc == expected, err_msg
+
+
+@pytest.mark.importance("low")
+@pytest.mark.topology(KnownTopology.LDAP)
+def test_ldap__empty_attribute(client: Client, ldap: LDAP):
+    """
+    :title: SSSD fails to store users if any of the requested attribute is empty
+    :setup:
+        1. Disable Syntax Checking
+        2. Add a User
+        3. Make home attribute of user empty
+        4. Add Groups
+        5. Start SSSD
+    :steps:
+        1. User exists
+        2. Groups are resolved
+        3. User should be able to log in
+    :expectedresults:
+        1. Id look up should success
+        2. Group look up should success
+        3. User log in should success
+    :customerscenario: True
+    """
+    ldap.ldap.modify("cn=config", replace={"nsslapd-syntaxcheck": "off"})
+    user = ldap.user("emp_user").add(password="Secret123")
+    user.modify(home="")
+
+    ldap.group("Group_1").add().add_member(member=user)
+    ldap.group("Group_2").add().add_member(member=user)
+
+    client.sssd.start()
+
+    assert client.tools.id("emp_user") is not None
+    for grp in ["Group_1", "Group_2"]:
+        assert client.tools.getent.group(grp) is not None
+    assert client.auth.ssh.password(user.name, "Secret123"), "User login failed!"
+
+
+@pytest.mark.importance("low")
+@pytest.mark.ticket(bz=785908)
+@pytest.mark.topology(KnownTopology.LDAP)
+def test_ldap__limit_search_base_group(client: Client, provider: LDAP):
+    """
+    :title: SSSD limits search base to 'ldap_search_base' DN for groups
+    :setup:
+        1. Create two ous
+        2. Netgroups are created in different ous
+        3. Members from different ous are added to netgroup
+    :steps:
+        1. Lookup netgroup with members from different ous
+        2. Set "ldap_search_base" to ou1 in the configuration and cleanly restart SSSD
+        3. Lookup netgroup with members from different ous
+    :expectedresults:
+        1. Netgroup exists and it contains members from both ous
+        2. SSSD is configured and cleanly restarted
+        3. Netgroup exists and it contains members only from ou1 in ldap_search_base
+    :customerscenario: True
+    """
+    ou1 = provider.ou("OU1").add()
+    ou2 = provider.ou("OU2").add()
+
+    ou1_grp1 = provider.netgroup("ou1_grp1", basedn=ou1).add()
+    ou1_grp1.add_member(host="h1", user="ou1_usr1", domain="ldap.test")
+
+    ou2_grp1 = provider.netgroup("ou2_grp1", basedn=ou2).add()
+    ou2_grp1.add_member(host="h2", user="ou2_usr1", domain="ldap.test")
+
+    ou2_grp2 = provider.netgroup("ou2_grp2", basedn=ou2).add()
+    ou2_grp2.add_member(ng=ou2_grp1)
+
+    ou1_grp2 = provider.netgroup("ou1_grp2", basedn=ou1).add()
+    ou1_grp2.add_member(ng=ou2_grp2)
+    ou1_grp2.add_member(ng=ou1_grp1)
+
+    client.sssd.start()
+    result = client.tools.getent.netgroup("ou1_grp2")
+    assert result is not None and result.name == "ou1_grp2", "Netgroup ou1_grp2 was not found!"
+    assert len(result.members) == 2
+    assert "(h1,ou1_usr1,ldap.test)" in result.members, "Member of ou1 'h1, ou1_usr1' is missing from 'ou1_grp2'."
+    assert "(h2,ou2_usr1,ldap.test)" in result.members, "Member of ou2 'h2, ou2_usr1' is missing from 'ou1_grp2'."
+
+    client.sssd.dom("test")["ldap_search_base"] = "ou=OU1,dc=ldap,dc=test"
+    client.sssd.restart(clean=True)
+
+    result = client.tools.getent.netgroup("ou1_grp2")
+    assert result is not None and result.name == "ou1_grp2", "Netgroup ou1_grp2 was not found!"
+    assert len(result.members) == 1
+    assert "(h1,ou1_usr1,ldap.test)" in result.members, "Member of ou1 'h1, ou1_usr1' is missing from 'ou1_grp2'."
+    assert (
+        "(h2,ou2_usr1,ldap.test)" not in result.members
+    ), "'ou1_grp2' members did not match the expected ones when search base is limited."
